﻿#region Imported Namespaces

//.NET common used namespaces
using System;
using System.Windows.Forms;
using System.Collections.Generic;

//Revit.NET common used namespaces
using Autodesk.Revit.ApplicationServices;
using Autodesk.Revit.Attributes;
using Autodesk.Revit.DB;
using Autodesk.Revit.UI;
using Autodesk.Revit.UI.Selection;
using System.Text;

#endregion

namespace RevitDevTV
{
    [Transaction(TransactionMode.Automatic)]
    [Regeneration(RegenerationOption.Manual)]
    public class AdskCommand : IExternalCommand
    {
        /// <summary>
        /// The one and only method required by the IExternalCommand interface,
        /// the main entry point for every external command.
        /// </summary>
        /// <param name="commandData">Input argument providing access to the Revit application and its documents and their properties.</param>
        /// <param name="message">Return argument to display a message to the user in case of error if Result is not Succeeded.</param>
        /// <param name="elements">Return argument to highlight elements on the graphics screen if Result is not Succeeded.</param>
        /// <returns>Cancelled, Failed or Succeeded Result code.</returns>
        public Result Execute(
            ExternalCommandData commandData,
            ref string message,
            ElementSet elements)
        {
            //TODO: Add your code here
            UIApplication uiApp = commandData.Application;
            UIDocument uiDoc = uiApp.ActiveUIDocument;

            //let's get the selection
            Selection sel = uiDoc.Selection;

            //now we can do a for each element in the selection
            foreach (Element ele in sel.Elements)
            {
                //let's create a string message with some
                //information about these elements

                string eleInfo = string.Format("Name: {0}\nCategory: {1}",
                    ele.Name, ele.Category.Name);

                //finally, show the message
                TaskDialog.Show("Element information", eleInfo);
            }

            //the first is access the document (DB)
            Document doc = uiDoc.Document;

            //create a filteredElementCollector object
            FilteredElementCollector doors = new FilteredElementCollector(doc);
            doors.OfClass(typeof(FamilyInstance));
            doors.OfCategory(BuiltInCategory.OST_Doors);

            //run through the collection
            foreach (FamilyInstance door in doors)
            {
                //create a string with information about the door
                StringBuilder doorInfo = new StringBuilder();
                doorInfo.AppendFormat("Name: {0}", door.Name);

                //let's access the collection of parameters
                foreach (Parameter param in door.Parameters)
                {
                    //the parameter name
                    doorInfo.AppendFormat("\nParameter {0} - Value: ",
                        param.Definition.Name);

                    //get the parameter type
                    switch (param.StorageType)
                    {
                        case StorageType.String:
                            doorInfo.Append(param.AsString());
                            break;
                        case StorageType.Double:
                            doorInfo.Append(param.AsDouble().ToString());
                            break;
                        default:
                            doorInfo.Append("ToDo: Homework");
                            break;
                    }
                }

                //show the information
                TaskDialog.Show("Door info", doorInfo.ToString());
            }


            //Must return some code
            return Result.Succeeded;
        }
    }
}
